{% extends 'generic/object.html' %}
{% load humanize %}
{% load helpers %}
{% load render_table from django_tables2 %}

{% block extra_tabs %}
<li role="presentation" class="nav-item">
  <a href="{% url 'plugins:nb_risk:vulnerability_affected_assets' pk=object.pk %}" class="nav-link{% if tab == 'affected_assets' %} active{% endif %}">
    Affected Assets
  </a>
</li>
{% endblock %}

{% block content %}
<div class="row mb-3">
    <div class="col col-md-6">
        <div class="card">
            <h5 class="card-header">Vulnerability</h5>
            <div class="card-body">
                <table class="table table-hover attr-table">
                    <tr>
                        <th scope="row">Name</th>
                        <td>{{ object.name }}</td>
                    </tr>
                    <tr>
                        <th scope="row">CVE</th>
                        <td>{{ object.cve }}</td>
                    </tr>
                    <tr>
                        <th scope="row">Description</th>
                        <td>{{ object.description }}</td>
                    </tr>
                </table>
            </div>
        </div>
        {% include 'inc/panels/tags.html' %}
    </div>
    <div class="col col-md-6">        
        <div class="card">
          <h5 class="card-header">Notes</h5>
          <div class="card-body">
            {{ object.notes | markdown  }}
          </div>
        </div>
      </div>
</div>
{% endblock %}

