{% extends 'generic/object.html' %}
{% load render_table from django_tables2 %}

{% block extra_tabs %}
<li role="presentation" class="nav-item">
  <a href="{% url 'plugins:nb_risk:vulnerability_affected_assets' pk=object.pk %}" class="nav-link{% if tab == 'affected_assets' %} active{% endif %}">
    Affected Assets
  </a>
</li>
{% endblock %}

{% block content %}
<div class="row mb-3">
  <div class="card-body" id="object_list">
    {% include 'htmx/table.html' %}
  </div>
</div>
{% endblock %}